// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'dart:async';

import 'package:wyatt_ui_components/wyatt_wyatt_ui_components.dart';
import 'package:wyatt_ui_kit/src/components/buttons/cubit/button_cubit.dart';

class SelectableButtonCubit extends ButtonCubit {
  @override
  FutureOr<void> onClickUpIn() async {
    if (state.isDisabled || state.isFreezed) {
      return;
    }
    emit(
      state.copyWith(state: ControlState.hovered, selected: !state.selected),
    );
  }

  @override
  FutureOr<void> onClickUpOut() async {
    if (state.isDisabled || state.isFreezed) {
      return;
    }
    emit(state.copyWith(state: ControlState.normal, selected: !state.selected));
  }

  FutureOr<void> select() async {
    if (state.isDisabled || state.isFreezed) {
      return;
    }

    emit(
      state.copyWith(selected: true),
    );
  }

  FutureOr<void> unselect() async {
    if (state.isDisabled || state.isFreezed) {
      return;
    }

    emit(
      state.copyWith(selected: false),
    );
  }
}
