// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:wyatt_ui_components/wyatt_wyatt_ui_components.dart';
import 'package:wyatt_ui_kit/src/components/cards/widgets/card_text.dart';
import 'package:wyatt_ui_kit/src/components/gradients/gradient_icon.dart';
import 'package:wyatt_ui_kit/src/domain/card_theme_extension.dart';

class SkillCardHeader extends StatelessWidget {
  const SkillCardHeader({
    super.key,
    this.icon,
    this.title,
    this.gradient,
    this.secondaryBackgroundColors,
  });

  final IconData? icon;
  final TextWrapper? title;
  final List<Color>? gradient;
  final Color? secondaryBackgroundColors;

  @override
  Widget build(BuildContext context) => Column(
        children: [
          if (icon != null) ...[
            Container(
              padding: const EdgeInsets.all(10),
              decoration: BoxDecoration(
                shape: BoxShape.circle,
                color: secondaryBackgroundColors ??
                    Theme.of(context)
                        .extension<CardThemeExtension>()
                        ?.secondaryBackgroundColors,
              ),
              child: gradient != null
                  ? GradientIcon(
                      icon,
                      size: 45,
                      gradient: LinearGradient(colors: gradient!),
                    )
                  : Icon(
                      icon,
                      size: 45,
                    ),
            ),
            const Gap(25),
            Column(
              children: [
                if (title != null) ...[
                  CardText(
                    title!.text,
                    textType: TextType.title,
                    style: title!.style,
                    gradient: title!.gradient,
                  ),
                ],
              ],
            )
          ],
        ],
      );
}
